@@ -8,8 +8,9 @@ import sys
 import json
 import time
 
-from .helper import is_macos
+from .helper import IS_PY3, is_macos
 from .conf import *
+from .m2c import swaggerhtml
 if M2C_VERSION == 'v3':
     from .m2c import goswagger3 as goswagger
 elif M2C_VERSION == 'v4':
@@ -188,7 +189,7 @@ def vendor():
     os.chdir(GOPHER_DIR)
     os.system('go mod vendor')
 
-def swaggerCodegen(lang, outputDir, pkg=''):
+def swaggerCodegen(lang, outputDir, pkg='', swaggerYamlPath=SWAGGER_YAML_PATH):
     if os.system('which swagger-codegen') != 0:
         print(Color.red('swagger-codgen 不存在, 安装参考: https://github.com/swagger-api/swagger-codegen'))
         if is_macos():
@@ -196,6 +197,23 @@ def swaggerCodegen(lang, outputDir, pkg=''):
             _run('brew install swagger-codegen')
         return
     if pkg == '':
-        _run('swagger-codegen generate -i %s -l %s -o %s' % (SWAGGER_YAML_PATH, lang, outputDir))
+        _run('swagger-codegen generate -i %s -l %s -o %s' % (swaggerYamlPath, lang, outputDir))
     else:
-        _run('swagger-codegen generate -i %s -l %s -o %s -DpackageName=%s' % (SWAGGER_YAML_PATH, lang, outputDir, pkg))
+        _run('swagger-codegen generate -i %s -l %s -o %s -DpackageName=%s' % (swaggerYamlPath, lang, outputDir, pkg))
+
+def swaggerHtmlDoc(apimodelPath, pkg=''):
+    html = swaggerhtml(apimodelPath)
+    savedir = os.path.dirname(apimodelPath)
+    savepath = os.path.join(savedir, 'swagger.yaml')
+    print(savedir, savepath)
+    fp = open(savepath, 'wb')
+    header = '# Code generated by m2c. DO NOT EDIT.\n'
+    if IS_PY3():
+        fp.write(header.encode('utf-8'))
+        fp.write(html.encode('utf-8'))
+    else:
+        fp.write(header)
+        fp.write(html)
+    fp.close()
+
+    swaggerCodegen('html2', savedir, pkg=pkg, swaggerYamlPath=savepath)
