@@ -277,8 +277,8 @@ class Swagger(object):
             d['info'] = self.info.todict()
         return d
 
-def genSwaggerContent():
-    lines = open('apimodel.txt', 'rb').readlines()
+def genSwaggerContent(apimodelPath = 'apimodel.txt'):
+    lines = open(apimodelPath, 'rb').readlines()
     if IS_PY3(): # py2 vs py3
         lines = list(map(lambda x: x.decode('utf-8'), lines))
     apiModel = ApiModel.fromLines(lines)
