@@ -42,11 +42,15 @@ vlogs = {
     '0.3.9': 'add swagger codegen',
     '0.4.0': 'add swagger security, json resp model',
     '0.4.1': 'add m2c init from git repo',
-    '0.4.2': 'fix pack'
+    '0.4.2': 'fix pack',
+    '0.4.3': 'add adhoc swaggerHtmlDoc cmd',
+    '0.4.4': 'add mgo _id type',
+    '0.4.5': 'add db model list',
+    '0.4.6': 'rm obj model new'
 }
 
 name = 'm2c'
-version = '0.4.2'
+version = '0.4.6'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
@@ -68,19 +72,21 @@ def change_log():
 
 
 def check_version():
-    import os
-    import random
-    from .conf import Color
-    if random.randint(0, 10) % 2 == 0:
-        return
-    # random check for speed up
-    change_log()
-    text = os.popen('pip search %s' % name).read()
-    need_update = False
-    for line in text.splitlines():
-        print(line)
-        line = line.strip()
-        if line.startswith('LATEST:'):
-            need_update = True
-    if need_update:
-        print(Color.red('run: pip install -U %s, update it!' % name))
+    return
+    # PyPI's XMLRPC API is currently disabled due to unmanageable load and will be deprecated in the near future.
+    # import os
+    # import random
+    # from .conf import Color
+    # if random.randint(0, 10) % 2 == 0:
+    #     return
+    # # random check for speed up
+    # change_log()
+    # text = os.popen('pip search %s' % name).read()
+    # need_update = False
+    # for line in text.splitlines():
+    #     print(line)
+    #     line = line.strip()
+    #     if line.startswith('LATEST:'):
+    #         need_update = True
+    # if need_update:
+    #     print(Color.red('run: pip install -U %s, update it!' % name))
